@@ -1,8 +1,8 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2021 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
-# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
+# Licence version 3 (GPL Version 3), copied verbatim in the file "LICENSE".   #
 #                                                                             #
 # In applying this licence, CERN does not waive the privileges and immunities #
 # granted to it by virtue of its status as an Intergovernmental Organization  #
@@ -12,6 +12,7 @@ import copy
 import logging
 import os
 import re
+from pathlib import Path
 
 from .defaults import DEFAULT_CHECKOUT_METHOD
 from .utils import _ContainedList, applyenv, write_patch
@@ -672,6 +673,11 @@ class Project:
 
         return os.path.join(path, filename)
 
+    def get_deployment_directory(self) -> Path:
+        from . import lbnightly_settings
+
+        return Path(lbnightly_settings().installations.path) / self.id()
+
 
 class ProjectsList(_ContainedList):
     """
